@@ -168,7 +168,7 @@ class CachedTranslation(ITranslation):
     """
 
     def __init__(self, underlying):
-        """Creates a TranslationCache.
+        """Creates a CachedTranslation.
 
         Args:
             translation (ITranslation): The underlying translation to cache.
@@ -213,8 +213,10 @@ def apply_packaged_translation(pkg, input_text, translator):
             logging_level='WARNING')
     stanza_sbd = stanza_pipeline(input_text)
     sentences = [sentence.text for sentence in stanza_sbd.sentences]
+    tokenized = [sp_processor.encode(sentence, out_type=str) for sentence in sentences]
     translated_batches = translator.translate_batch(
-            [sp_processor.encode(sentence, out_type=str) for sentence in sentences],
+            tokenized,
+            replace_unknowns=True,
             max_batch_size=32,
             length_penalty=0.2)
     translated_tokens = []
